spacepy.irbempy.get_Lm — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »

# spacepy.irbempy.get_Lm

`spacepy.irbempy.` `get_Lm`(ticks, loci, alpha, extMag='T01STORM', intMag='IGRF', IGRFset=0, omnivals=None)

  Return the MacIlwain L value for a given location, time and model

  Parameters: | - ticks (Ticktock class) : containing time information loci (Coords class) : containing spatial information alpha (list or ndarray) : pitch angles in degrees extMag (string) : optional; will choose the external magnetic field model possible values [‘0’, ‘MEAD’, ‘T87SHORT’, ‘T87LONG’, ‘T89’, ‘OPQUIET’, ‘OPDYN’, ‘T96’, ‘OSTA’, ‘T01QUIET’, ‘T01STORM’, ‘T05’, ‘ALEX’] intMag (string) : optional: select the internal field model possible values [‘IGRF’,’EDIP’,’JC’,’GSFC’,’DUN’,’CDIP’] For full details see get_Lstar omni values as dictionary (optional) : if not provided, will use lookup table
  Returns: | - results (dictionary) : containing keys: Lm, Bmin, Blocal (or Bmirr), Xj, MLT if pitch angles provided in “alpha” then drift shells are calculated and “Bmirr” is returned if not provided, then “Blocal” at spacecraft is returned.

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »